@@ -1,5 +1,8 @@
 #!/usr/bin/perl -s 
 
+eval 'exec /usr/bin/perl -s  -S $0 ${1+"$@"}'
+    if 0; # not running under some shell
+
 use lib '.';
 use Tk;                   #LOAD TK STUFF
 use Tk::BrowseEntry;
